Learn R Programming

rWCVP (version 1.2.4)

get_area_name: Get area description from vector of area codes

Description

Get area description from vector of area codes

Usage

get_area_name(area_codes)

Value

Character. Either a vector of length one, with a name for the set of Level 3 areas, or (if no name exists for that set of areas) the input vector of codes.

Arguments

area_codes

Character vector containing the set of codes to be mapped to a name.

Details

Usually used as an inverse function for get_wgsrpd3_codes. Useful for condensing sets of codes for e.g. file names, plotting and table formatting.

Examples

Run this code
get_area_name(get_wgsrpd3_codes("Brazil"))

Run the code above in your browser using DataLab