Generate a species checklist from WCVP
wcvp_checklist(
taxon = NULL,
taxon_rank = c("species", "genus", "family", "order", "higher"),
area_codes = NULL,
synonyms = TRUE,
render_report = FALSE,
native = TRUE,
introduced = TRUE,
extinct = TRUE,
location_doubtful = TRUE,
hybrids = FALSE,
infraspecies = TRUE,
report_filename = NULL,
report_dir = NULL,
report_type = c("alphabetical", "taxonomic"),
wcvp_names = NULL,
wcvp_distributions = NULL
)Data frame with filtered data and, if render_report=TRUE. a report HTML file.
Character. Taxon to be included. Defaults to NULL (no taxonomic filter; all taxa).
Character. One of "species", "genus", "family", "order" or "higher", giving the rank of the value/s in taxon. Must be specified unless taxon is NULL.
Character. One or many WGSPRD level 3 region codes. Defaults to NULL (global).
Logical. Include synonyms in checklist (see Details)? Defaults to TRUE.
Logical. Render the checklist as a markdown report? Defaults to FALSE.
Logical. Include species occurrences not flagged as introduced, extinct or doubtful? Defaults to TRUE.
Logical. Include species occurrences flagged as introduced? Defaults to TRUE.
Logical. Include species occurrences flagged as extinct? Defaults to TRUE.
Logical. Include species occurrences flagged as location_doubtful? Defaults to TRUE.
Logical. Include hybrid species in checklist? Defaults to FALSE.
Logical. Include hybrid species in checklist? Defaults to TRUE.
Character. Name for the HTML file. Defaults to taxon_area_type.html
Character. Directory for the HTML file to be saved in. Must be provided by user.
Character; one of "alphabetical" (the default) or "taxonomic". Should the generated checklist be sorted alphabetically, or by taxonomic status?
A data frame of taxonomic names from WCVP version 7 or later.
If NULL (the default), names will be loaded from rWCVPdata::wcvp_names.
A data frame of distributions from WCVP version 7 or later.
If NULL (the default), distributions will be loaded from rWCVPdata::wcvp_names.
The synonyms argument can be used to limit names to those that are Accepted. If synonyms = TRUE then invalid, illegitimate and other non-accepted names are also included (i.e., the checklist is not limited to names for which taxon_status == "Synonym").
Two styles of checklist are supported in rWCVP - alphabetical and taxonomic.
In an alphabetical checklist, all names are arranged alphabetically with accepted names in bold, and synonyms are followed by their accepted name.
For a taxonomic checklist, names are grouped by their accepted names, and synonyms are listed beneath. Both types of checklist include author, publication and distribution information, though note that family headings are only supported in alphabetical checklists (due to the additional grouping requirement of the taxonomic format).
# These examples take >10 seconds to run and require 'rWCVPdata'
# \donttest{
if(requireNamespace("rWCVPdata")){
wcvp_checklist(taxon = "Myrtaceae", taxon_rank = "family", area = get_wgsrpd3_codes("Brazil"))
wcvp_checklist(taxon = "Ferns", taxon_rank = "higher", area = get_wgsrpd3_codes("New Zealand"))
}
# }
Run the code above in your browser using DataLab